@@ -5,8 +5,8 @@ import dataclasses
 import logging
 from functools import cached_property
 from typing import (
-    TYPE_CHECKING, Any, Callable, Dict, FrozenSet, Generic, List, Optional,
-    Tuple, TypeVar, Union, cast
+    TYPE_CHECKING, Any, Callable, Dict, FrozenSet, Generic, Hashable, List,
+    Optional, Tuple, TypeVar, Union, cast
 )
 
 import geojson
@@ -14,9 +14,9 @@ import numpy as np
 import xarray as xr
 from shapely.geometry import Point, Polygon
 from shapely.geometry.base import BaseGeometry
-from shapely.strtree import STRtree
 
 from emsarray import operations, utils
+from emsarray.compat.shapely import SpatialIndex
 from emsarray.plot import (
     _requires_plot, animate_on_figure, plot_on_figure,
     polygons_to_patch_collection
@@ -35,7 +35,7 @@ if TYPE_CHECKING:
 logger = logging.getLogger(__name__)
 
 
-DataArrayOrName = Union[str, xr.DataArray]
+DataArrayOrName = Union[Hashable, xr.DataArray]
 
 #: Some type that can enumerate the different :ref:`grid types <grids>`
 #: present in a dataset.
@@ -230,19 +230,20 @@ class Format(abc.ABC, Generic[GridKind, Index]):
         This is useful for methods that support being passed either
         the name of a data array or a data array instance.
         """
-        if isinstance(data_array, str):
-            return self.dataset[data_array]
-        else:
+        if isinstance(data_array, xr.DataArray):
             utils.check_data_array_dimensions_match(self.dataset, data_array)
             return data_array
+        else:
+            return self.dataset[data_array]
 
-    @abc.abstractmethod
-    def get_time_name(self) -> str:
+    def get_time_name(self) -> Hashable:
         """Get the name of the time variable in this dataset."""
-        pass
+        for name, variable in self.dataset.variables.items():
+            if variable.attrs.get('standard_name') == 'time':
+                return str(name)
+        raise KeyError("Dataset does not have a time dimension")
 
-    @abc.abstractmethod
-    def get_depth_name(self) -> str:
+    def get_depth_name(self) -> Hashable:
         """Get the name of the layer depth coordinate variable.
         For datasets with multiple depth variables, this should be the one that
         represents the centre of the layer, not the bounds.
@@ -250,10 +251,9 @@ class Format(abc.ABC, Generic[GridKind, Index]):
         Note that this is the name of the coordinate variable,
         not the name of the dimension, for datasets where these differ.
         """
-        pass
+        return self.get_all_depth_names()[0]
 
-    @abc.abstractmethod
-    def get_all_depth_names(self) -> List[str]:
+    def get_all_depth_names(self) -> List[Hashable]:
         """Get the names of all depth layers.
         Some datasets include both a depth layer centre,
         and the depth layer 'edges'.
@@ -261,7 +261,31 @@ class Format(abc.ABC, Generic[GridKind, Index]):
         Note that this is the names of the coordinate variables,
         not the names of the dimensions, for datasets where these differ.
         """
-        pass
+        depth_names = []
+        for name in self.dataset.variables.keys():
+            data_array = self.dataset[name]
+
+            if not (
+                data_array.attrs.get('axis') == 'Z'
+                or data_array.attrs.get('cartesian_axis') == 'Z'
+                or data_array.attrs.get('coordinate_type') == 'Z'
+                or data_array.attrs.get('standard_name') == 'depth'
+            ):
+                continue
+
+            try:
+                # If the variable is defined on a grid,
+                # it is more likely to be a bathymetry variable
+                # not the coordinate for the depth layers.
+                self.get_grid_kind_and_size(data_array)
+                continue
+            except ValueError:
+                # The variable isn't on a grid - this is good!
+                pass
+
+            depth_names.append(name)
+
+        return depth_names
 
     def get_depths(self) -> np.ndarray:
         """Get the depth of each vertical layer in this dataset.
@@ -858,7 +882,7 @@ class Format(abc.ABC, Generic[GridKind, Index]):
         return cast(np.ndarray, mask)
 
     @cached_property
-    def spatial_index(self) -> STRtree:
+    def spatial_index(self) -> SpatialIndex[SpatialIndexItem[Index]]:
         """
         A shapely :class:`strtree.STRtree` spatial index of all cells in this dataset.
         This allows for fast spatial lookups, querying which cells lie at
@@ -878,25 +902,25 @@ class Format(abc.ABC, Generic[GridKind, Index]):
         .. code-block:: python
 
             indices = [
-                item.index for item in dataset.ems.spatial_index.query(shape)
-                if item.polygon.intersects(shape)
+                item.index
+                for item, polygon in dataset.ems.spatial_index.query(shape)
+                if polygon.intersects(shape)
             ]
 
         See also
         --------
         :class:`.SpatialIndexItem`
-        :class:`strtree.STRtree`
         """
         logger.info("Building spatial index...")
         with utils.PerfTimer() as timer:
             items = [
-                SpatialIndexItem(index, self.unravel_index(index), poly)
+                (poly, SpatialIndexItem(index, self.unravel_index(index), poly))
                 for index, poly in enumerate(self.polygons)
                 if poly is not None
             ]
-            str_tree = STRtree([item.polygon for item in items], items=items)
+            spatial_index = SpatialIndex(items)
         logger.debug("Build spatial index in %f seconds", timer.elapsed)
-        return str_tree
+        return spatial_index
 
     def get_index_for_point(
         self,
@@ -928,8 +952,9 @@ class Format(abc.ABC, Generic[GridKind, Index]):
         or if the geometry of the dataset contains overlapping polygons.
         """
         hits: List[SpatialIndexItem] = sorted(
-            item for item in self.spatial_index.query_items(point)
-            if item.polygon.intersects(point)
+            item
+            for polygon, item in self.spatial_index.query(point)
+            if polygon.intersects(point)
         )
         if len(hits) > 0:
             return hits[0]
@@ -1051,7 +1076,12 @@ class Format(abc.ABC, Generic[GridKind, Index]):
         ])
 
     @abc.abstractmethod
-    def make_clip_mask(self, clip_geometry: BaseGeometry) -> xr.Dataset:
+    def make_clip_mask(
+        self,
+        clip_geometry: BaseGeometry,
+        *,
+        buffer: int = 0,
+    ) -> xr.Dataset:
         """
         Make a new Dataset that can be used to clip this dataset to only the
         cells that intersect some geometry.
@@ -1065,9 +1095,14 @@ class Format(abc.ABC, Generic[GridKind, Index]):
 
         Parameters
         ----------
-        clip_geometry
+        clip_geometry : BaseGeometry
             The desired area to cut out. This can be any shapely geometry type,
             but will most likely be a polygon
+        buffer : int, optional
+            If set to a positive integer,
+            a buffer of that many cells will be added around the clip region.
+            This is useful if you need to clip to a particular area,
+            but also would like to do some interpolation on the output cells.
 
         Returns
         -------
@@ -1099,28 +1134,56 @@ class Format(abc.ABC, Generic[GridKind, Index]):
         or save the dataset to disk somewhere outside of the working directory
         before the working directory is cleaned up.
 
-        :param clip_mask: The mask, as made by :meth:`make_clip_mask`.
-        :param work_dir: A directory where temporary files can be written to.
-            Callers must create and manage this temporary directory, perhaps
-            using :obj:`tempfile.TemporaryDirectory`.
-        :returns: A new :class:`~xarray.Dataset` clipped using the mask
+        Parameters
+        ----------
+        clip_mask : xarray.Dataset
+            The mask, as made by :meth:`make_clip_mask`.
+        work_dir : str or pathlib.Path
+            A directory where temporary files can be written to.
+            Callers must create and manage this temporary directory,
+            perhaps using :obj:`tempfile.TemporaryDirectory`.
+
+        Returns
+        -------
+        xarray.Dataset
+            A new :class:`~xarray.Dataset` clipped using the mask
         """
 
-    def clip(self, clip_geomery: BaseGeometry, work_dir: Pathish) -> xr.Dataset:
+    def clip(
+        self,
+        clip_geomery: BaseGeometry,
+        work_dir: Pathish,
+        *,
+        buffer: int = 0,
+    ) -> xr.Dataset:
         """
         Generates a clip mask and applies it in one step.
 
         See the documentation for :meth:`.make_clip_mask` and
         :meth:`.apply_clip_mask` for more details.
 
-        :param clip_geomery: The desired area to cut out. This can be any
-            shapely geometry type, but will most likely be a polygon
-        :param work_dir: A directory where temporary files can be written to.
-            Callers must create and manage this temporary directory, perhaps
-            using :obj:`tempfile.TemporaryDirectory`.
-        :returns: A new :class:`~xarray.Dataset` clipped using the mask
+        Parameters
+        ----------
+        clip_geometry : BaseGeometry
+            The desired area to cut out.
+            This can be any shapely geometry type,
+            but will most likely be a polygon
+        work_dir : str or pathlib.Path
+            A directory where temporary files can be written to.
+            Callers must create and manage this temporary directory,
+            perhaps using :obj:`tempfile.TemporaryDirectory`.
+        buffer : int, optional
+            If set to a positive integer,
+            a buffer of that many cells will be added around the clip region.
+            This is useful if you need to clip to a particular area,
+            but also would like to do some interpolation on the output cells.
+
+        Returns
+        -------
+        xarray.Dataset
+            A new :class:`~xarray.Dataset` clipped using the mask
         """
-        mask = self.make_clip_mask(clip_geomery)
+        mask = self.make_clip_mask(clip_geomery, buffer=buffer)
         return self.apply_clip_mask(mask, work_dir=work_dir)
 
     def to_netcdf(self, path: Pathish, **kwargs: Any) -> None:
@@ -1128,8 +1191,12 @@ class Format(abc.ABC, Generic[GridKind, Index]):
         Save this dataset to a netCDF file, and also fix up the time units to
         make the EMS compatible.
         """
+        try:
+            time_variable = self.get_time_name()
+        except KeyError:
+            time_variable = None
         utils.to_netcdf_with_fixes(
-            self.dataset, path, time_variable=self.get_time_name(), **kwargs)
+            self.dataset, path, time_variable=time_variable, **kwargs)
 
     # Aliases for emsarray.operations
 
