@@ -29,9 +29,6 @@ import pytz
 import xarray as xr
 from packaging.version import Version
 from xarray.coding import times
-from xarray.coding.variables import (
-    CFMaskCoder, CFScaleOffsetCoder, UnsignedIntegerCoder
-)
 from xarray.core.common import contains_cftime_datetimes
 
 from emsarray.types import Pathish
@@ -84,7 +81,7 @@ class PerfTimer:
 def to_netcdf_with_fixes(
     dataset: xr.Dataset,
     path: Pathish,
-    time_variable: Optional[str] = None,
+    time_variable: Optional[Hashable] = None,
     **kwargs: Any,
 ) -> None:
     """Saves a :class:`xarray.Dataset` to a netCDF4 file,
@@ -181,7 +178,7 @@ def format_time_units_for_ems(units: str, calendar: Optional[str] = DEFAULT_CALE
 
 def fix_time_units_for_ems(
     dataset_path: Pathish,
-    variable_name: str,
+    variable_name: Hashable,
 ) -> None:
     """
     Updates time units in a file so they are compatible with EMS.
@@ -340,34 +337,9 @@ def _update_no_clobber(source: Mapping[Hashable, Any], dest: MutableMapping[Hash
             dest[key] = value
 
 
-def maybe_mask_and_scale(variable: xr.Variable, name: Optional[str] = None) -> xr.Variable:
-    """Mask and scale a variable, if it appears to not have been masked and
-    scaled already. Does nothing if the data is already masked or scaled.
-    """
-    mask_and_scale_keys = ['_FillValue', 'missing_value', 'scale_factor', 'add_offset']
-    if (
-        # Check if `values` is already masked
-        np.ma.isarray(variable.values)
-        # Look for telltale attributes
-        or not any(key in variable.attrs for key in mask_and_scale_keys)
-    ):
-        return variable
-    return mask_and_scale(variable)
-
-
-def mask_and_scale(variable: xr.Variable, name: Optional[str] = None) -> xr.Variable:
-    """Mask and scale a variable by running the relevant xarray Coders.
-    Does the same thing as if `mask_and_scale=True` had been passed when
-    opening the dataset.
-    """
-    for coder in [UnsignedIntegerCoder(), CFMaskCoder(), CFScaleOffsetCoder()]:
-        variable = coder.decode(variable, name=name)
-    return variable
-
-
 def extract_vars(
     dataset: xr.Dataset,
-    variables: Iterable[str],
+    variables: Iterable[Hashable],
     keep_bounds: bool = True,
     errors: Literal['raise', 'ignore'] = 'raise',
 ) -> xr.Dataset:
@@ -404,7 +376,8 @@ def extract_vars(
         missing_variables = variables - set(cast(Iterable[str], dataset.variables.keys()))
         if missing_variables:
             raise ValueError(
-                f"Variables {sorted(missing_variables)!r} do not exist in the dataset"
+                f"Variables {sorted(missing_variables, key=str)!r} "
+                "do not exist in the dataset"
             )
 
     if keep_bounds:
@@ -437,7 +410,10 @@ def pairwise(iterable: Iterable[_T]) -> Iterable[Tuple[_T, _T]]:
     return zip(a, b)
 
 
-def dimensions_from_coords(dataset: xr.Dataset, coordinate_names: List[str]) -> List[str]:
+def dimensions_from_coords(
+    dataset: xr.Dataset,
+    coordinate_names: List[Hashable],
+) -> List[Hashable]:
     """
     Get the names of the dimensions for a set of coordinates.
 
@@ -450,7 +426,7 @@ def dimensions_from_coords(dataset: xr.Dataset, coordinate_names: List[str]) ->
 
     Returns
     -------
-    list of str
+    list of Hashable
         The name of the relevant dimension for each coordinate variable.
     """
     dimensions = []
@@ -459,9 +435,8 @@ def dimensions_from_coords(dataset: xr.Dataset, coordinate_names: List[str]) ->
         data_array = dataset.variables[coordinate_name]
         if len(data_array.dims) > 1:
             raise ValueError(
-                f"Coordinate variable {coordinate_name} has more than one dimension: "
-                + str(data_array.dims)
-            )
+                f"Coordinate variable {coordinate_name} has more "
+                "than one dimension: {data_array.dims}")
         dimensions.append(data_array.dims[0])
 
     return dimensions
